@@ -3,17 +3,12 @@
 
 # Copyright (c) Mito.
 # Distributed under the terms of the Modified BSD License.
-from typing import TYPE_CHECKING, Any, Dict, Collection, List, Optional, Tuple
+from typing import Any, Dict, Collection, List, Optional, Tuple
 import pandas as pd
-from mitosheet.mito_analytics import log
+from mitosheet.telemetry.telemetry_utils import log
 from mitosheet.preprocessing.preprocess_step_performer import \
     PreprocessStepPerformer
-
-# To avoid circular imports
-if TYPE_CHECKING:
-    from mitosheet.steps_manager import StepsManager
-else: 
-    StepsManager = Any
+from mitosheet.types import StepsManagerType
 
 
 class CheckArgsTypePreprocessStepPerformer(PreprocessStepPerformer):
@@ -42,12 +37,12 @@ class CheckArgsTypePreprocessStepPerformer(PreprocessStepPerformer):
         for arg in args:
             if not isinstance(arg, pd.DataFrame) and not isinstance(arg, str) and not arg is None:
                 error_message = f'Invalid argument passed to sheet: {arg}. Please pass all dataframes or paths to CSV files.'
-                log('mitosheet_sheet_call_failed', {'error': error_message})
+                log('mitosheet_sheet_call_failed', {'error': error_message}, failed=True)
                 raise ValueError(error_message)
         
         # We do filter out all the None arguments
         return [arg for arg in args if arg is not None], None
 
     @classmethod
-    def transpile(cls, steps_manager: StepsManager, execution_data: Optional[Dict[str, Any]]) -> List[str]:
+    def transpile(cls, steps_manager: StepsManagerType, execution_data: Optional[Dict[str, Any]]) -> List[str]:
         return []
